# maimai-utils

![Static Badge](https://img.shields.io/badge/python-3.10%2B-blue?logo=python&logoColor=edb641)
![Static Badge](https://img.shields.io/badge/maimai-1.40%2B-green)
![Static Badge](https://img.shields.io/badge/Dev-0.1.40-orange)
[![CodeTime Badge](https://img.shields.io/endpoint?style=flat&color=222&url=https%3A%2F%2Fapi.codetime.dev%2Fshield%3Fid%3D25986%26project%3Dmaimai-utils%26in=0)](https://codetime.dev)

`maimai-utils`是使用SEGA所属的街机音游maimai的数据进行开发的Python模块，用于快速查询游戏相关的数据。

施工中🚧🚧🚧！

## 安装
```shell
pip install maimai_utils
```

## 文档

详见`/doc`目录内或[maimai-utils文档](https://vercel.kyoku.top)。

## 常见问题

## 更新日志
`0.1.40`
* 增加了空分数对象
* 修复一些bug
* 从这个版本开始修改了版本号的计数方式（后面多了个0）

`0.1.3`
* 加入了分数计算以及分数仿真的功能，现在可以生成一个看起来非常合理的成绩了

`0.1.2`
* 应群友要求增加了`maiquery`的查询种类
* 分数计算功能完成了一半，不建议使用，后面还有很多要改
* 修改了一下文件结构和命名，文件层级也有修改

`0.1.1`
* 第一次更新！
* 现在可以通过`maiquery`来查找歌曲数据对象了